asr.plasmafrequency
===================

.. automodule:: asr.plasmafrequency

   
   
   .. rubric:: Functions

   
   .. autofunction:: get_kpts_size
   .. autofunction:: webpanel
   
   

   
   
   .. rubric:: Classes

   
   .. autoclass:: Result
      :members:
   
   

   
   
   